@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-error-viewer-extension.c,v 1.30 2006/09/13 19:01:07 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
@@ -31,8 +31,9 @@
 
 #include <epiphany/ephy-extension.h>
 #include <epiphany/ephy-window.h>
-#include <epiphany/ephy-embed-shell.h>
 #include <epiphany/ephy-embed.h>
+#include <epiphany/ephy-embed-container.h>
+#include <epiphany/ephy-embed-shell.h>
 
 #include <gtk/gtkaction.h>
 #include <gtk/gtkactiongroup.h>
@@ -150,7 +151,7 @@ ephy_error_viewer_extension_register_type (GTypeModule *module)
 					    G_TYPE_OBJECT,
 					    "EphyErrorViewerExtension",
 					    &our_info, 0);
-	
+
 	g_type_module_add_interface (module,
 				     type,
 				     EPHY_TYPE_EXTENSION,
@@ -225,7 +226,7 @@ ephy_error_viewer_extension_validate (GtkAction *action,
 
 	dialog = data->extension->priv->dialog;
 
-	embed = ephy_window_get_active_embed (data->window);
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (data->window));
 
 	ephy_dialog_show (EPHY_DIALOG (dialog));
 
@@ -242,7 +243,7 @@ ephy_error_viewer_extension_check_links	(GtkAction *action,
 
 	dialog = data->extension->priv->dialog;
 
-	embed = ephy_window_get_active_embed (data->window);
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (data->window));
 
 	ephy_dialog_show (EPHY_DIALOG (dialog));
 
@@ -269,11 +270,10 @@ free_error_viewer_cb_data (gpointer data)
 static void
 update_actions (EphyWindow *window)
 {
-	EphyTab *tab;
 	EphyEmbed *embed;
 	GtkAction *action1;
 	GtkAction *action2; /* You can tell I didn't want to think... */
-	char *content_type;
+	EphyEmbedDocumentType content_type;
 	GValue sensitive = { 0, };
 
 	g_return_if_fail (EPHY_IS_WINDOW (window));
@@ -286,10 +286,10 @@ update_actions (EphyWindow *window)
 	action2 = gtk_ui_manager_get_action (GTK_UI_MANAGER (ephy_window_get_ui_manager (window)),
 					     "/menubar/ToolsMenu/CheckLinks");
 
-	tab = ephy_window_get_active_tab (window);
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 
 	/* Not finished loading? */
-	if (ephy_tab_get_load_status (tab) == TRUE)
+	if (ephy_embed_get_load_status (embed) == TRUE)
 	{
 		g_object_set_property (G_OBJECT (action1),
 				       "sensitive", &sensitive);
@@ -299,21 +299,16 @@ update_actions (EphyWindow *window)
 		return;
 	}
 
-	embed = ephy_tab_get_embed (tab);
-
-	content_type = mozilla_get_content_type (embed);
+	content_type = ephy_embed_get_document_type (embed);
 
 	if (content_type &&
-            ((strcmp (content_type, "text/html") == 0)
-             || (strcmp (content_type, "application/xhtml+xml") == 0)
-             || (strcmp (content_type, "application/xml") == 0)
-             || (strcmp (content_type, "text/xml") == 0)))
+            ((content_type == EPHY_EMBED_DOCUMENT_HTML)
+             || (content_type == EPHY_EMBED_DOCUMENT_XML))
+        )
 	{
 		g_value_set_boolean (&sensitive, TRUE);
 	}
 
-	g_free (content_type);
-
 	g_object_set_property (G_OBJECT (action1), "sensitive", &sensitive);
 	g_object_set_property (G_OBJECT (action2), "sensitive", &sensitive);
 
@@ -321,7 +316,7 @@ update_actions (EphyWindow *window)
 }
 
 static void
-load_status_cb (EphyTab *tab,
+load_status_cb (EphyEmbed *embed,
 		GParamSpec *pspec,
 		EphyWindow *window)
 {
@@ -343,19 +338,19 @@ switch_page_cb (GtkNotebook *notebook,
 static void
 impl_attach_tab (EphyExtension *extension,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
-	g_signal_connect_after (tab, "notify::load-status",
+	g_signal_connect_after (embed, "notify::load-status",
 				G_CALLBACK (load_status_cb), window);
 }
 
 static void
 impl_detach_tab (EphyExtension *extension,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
 	g_signal_handlers_disconnect_by_func
-		(tab, G_CALLBACK (load_status_cb), window);
+		(embed, G_CALLBACK (load_status_cb), window);
 }
 #endif /* HAVE_OPENSP */
 
